@@ -1,10 +1,14 @@
 """Commands to provide additional feature on app, such as list all the apps"""
+import json
+
+import requests
 from deepchain import log
 from deepchain.cli import BaseCLICommand
 
 from .apps_utils import (
-    display_apps_infos,
+    display_apps_info,
     display_config_info,
+    display_public_apps,
     get_app_info,
     get_apps_config,
     remove_app,
@@ -13,12 +17,13 @@ from .apps_utils import (
 
 
 def app_command_factory(args):
-    return AppsCommmand(args.infos, args.reset, args.delete, args.config)
+    return AppsCommand(args.info, args.reset, args.delete, args.config, args.public)
 
 
-class AppsCommmand(BaseCLICommand):
-    def __init__(self, infos: bool, reset: bool, delete: str, config: bool):
-        self.infos = infos
+class AppsCommand(BaseCLICommand):
+    def __init__(self, info: bool, reset: bool, delete: str, config: bool, public: bool):
+        self.info = info
+        self.public = public
         self.reset = reset
         self.delete = delete
         self.config = config
@@ -26,13 +31,13 @@ class AppsCommmand(BaseCLICommand):
     @staticmethod
     def register_subcommand(parser):
         apps_parser = parser.add_parser(
-            name="apps", help="gives infos on apps create locally, delete or reset apps"
+            name="apps", help="gives info on apps create locally, delete or reset apps"
         )
 
         apps_parser.add_argument(
-            "--infos",
+            "--info",
             action="store_true",
-            help="list all apps' infos",
+            help="list all apps' info",
         )
 
         apps_parser.add_argument(
@@ -54,10 +59,16 @@ class AppsCommmand(BaseCLICommand):
             help="show URL deployement config",
         )
 
+        apps_parser.add_argument(
+            "--public",
+            action="store_true",
+            help="show public apps",
+        )
+
         apps_parser.set_defaults(func=app_command_factory)
 
     def run(self):
-        if self.infos:
+        if self.info:
             config = get_apps_config()
 
             if len(config) == 0:
@@ -65,7 +76,7 @@ class AppsCommmand(BaseCLICommand):
                 print("No apps to display")
                 print("-------------------")
             else:
-                display_apps_infos(config)
+                display_apps_info(config)
 
         if self.config:
             display_config_info()
@@ -89,3 +100,16 @@ class AppsCommmand(BaseCLICommand):
             if answer == "y":
                 remove_app(self.delete)
                 log.info("Remove App %s", self.delete)
+
+        if self.public:
+            self.show_public_apps()
+
+    @staticmethod
+    def show_public_apps():
+        """List all the public app from the hub"""
+        result = requests.get(url="https://api.prod.deepchain.bio/public-apps")
+        if result.status_code >= 300:
+            log.debug(f"{result.content} : {result.content}")
+            exit(0)
+        apps_info = json.loads(result.content)
+        display_public_apps(apps_info)
