@@ -3,10 +3,12 @@
 #!/usr/bin/python3 # noqa: E265
 import argparse
 
-from .download import DownloadCommmand
-from .apps import AppsCommmand
+from .apps import AppsCommand
 from .auth import AuthCommand
 from .deploy import DeployCommand
+from .download import DownloadCommmand
+
+# from .inference import InferenceCommand
 from .scaffold import CreateCommand
 
 
@@ -21,8 +23,9 @@ def main():
     AuthCommand.register_subcommand(commands_parser)
     CreateCommand.register_subcommand(commands_parser)
     DeployCommand.register_subcommand(commands_parser)
-    AppsCommmand.register_subcommand(commands_parser)
+    AppsCommand.register_subcommand(commands_parser)
     DownloadCommmand.register_subcommand(commands_parser)
+    # InferenceCommand.register_subcommand(commands_parser)
 
     args = parser.parse_args()
 
