@@ -1,10 +1,9 @@
 """deploy modules helps for the deployement of application on deepchain"""
-import configparser
 from argparse import ArgumentParser
 
-import pkg_resources
 from deepchain import log
 from deepchain.cli import BaseCLICommand
+from deepchain.cli.cli_utils import get_config_url
 from deepchain.utils.validation import _check_app_files, _check_checkpoint_files
 
 from .apps_utils import (
@@ -50,10 +49,7 @@ class DeployCommand(BaseCLICommand):
         Check App to be deployed with validation function
         Upload checkpoint if needed
         """
-        config = configparser.ConfigParser()
-        path_config = pkg_resources.resource_filename("deepchain", "cli/config.ini")
-        config.read(path_config)
-        url = config["APP"]["DEEP_CHAIN_URL"]
+        url = get_config_url()
         configuration = get_configuration()
         pat = configuration["pat"]
 
@@ -100,14 +96,8 @@ class DeployCommand(BaseCLICommand):
 
         if self.checkpoint:
             _check_checkpoint_files(app_name)
-            req = upload_checkpoint(
+            _ = upload_checkpoint(
                 app_dir, app_name, pat, f"{url}/apps/", configuration["size_limit"]
             )
-            if req.status_code != 200:
-                log.warning("api return %s stopping operation", req.status_code)
-                log.warning("Checkpoint not uploaded.")
-                return
-
-            log.info("Checkpoint has been uploaded.")
 
         return
