@@ -1,13 +1,13 @@
 """deploy modules helps for the deployement of application on deepchain"""
-import configparser
 import os
 import shutil
 from argparse import ArgumentParser
 
-import pkg_resources
 import requests
+from deepchain import log
 from deepchain.cli import BaseCLICommand
-from deepchain.cli.apps_utils import save_app
+from deepchain.cli.apps_utils import check_app_name, save_app
+from deepchain.cli.cli_utils import get_config_url
 
 
 def download_command_factory(args):
@@ -44,18 +44,28 @@ class DownloadCommmand(BaseCLICommand):
         """
         Download public app
         """
-        config = configparser.ConfigParser()
-        config.read(pkg_resources.resource_filename("deepchain", "cli/config.ini"))
-        url = config["APP"]["DEEP_CHAIN_URL"]
+        url = get_config_url()
         if os.path.exists(f"{self.app_dir}") and len(os.listdir((f"{self.app_dir}"))) > 0:
-            print("destination folder is not empty, exiting.")
+            log.critical("destination folder is not empty, exiting.")
             return
+
+        check_app_name(self.app_dir)
         os.mkdir(f"{self.app_dir}")
         self.unpack(self.download_tar(url))
-        [self.unpack(f"{self.app_dir}/{f}") for f in os.listdir(self.app_dir)]
-        save_app(self.app_name, self.app_dir)
+        _ = [self.unpack(f"{self.app_dir}/{f}") for f in os.listdir(self.app_dir)]
+        save_app(self.app_dir, self.app_dir)
 
-    def download_tar(self, url):
+    def download_tar(self, url: str) -> str:
+        """Download tar file from the public apps-hub
+
+        Only apps with public tags are available
+
+        Args:
+            url (str): url of the API
+
+        Returns:
+            [str]: path of the download app
+        """
         req = requests.get(f"{url}/public-apps/{self.app_name}")
         if req.status_code != 200:
             print(f"api returning {req.status_code}, exiting.")
@@ -64,7 +74,12 @@ class DownloadCommmand(BaseCLICommand):
             file.write(req.content)
         return f"{self.app_dir}/tmp.tar"
 
-    def unpack(self, file):
+    def unpack(self, file: str):
+        """Unpack tar file in proper folder
+
+        Args:
+            file (str): path of the tar file
+        """
         dest = self.app_dir
         if file.endswith("_checkpoints.tar"):
             dest = os.path.join(self.app_dir, "checkpoint")
